@@ -123,9 +123,9 @@ static XFontSet current_fontset = NULL;
 		XDrawImageString16(dpy, win, gc, x, y, (XChar2b *)str, n); \
 	} while (0)
 
-static int check_fontset_sanity __ARGS((XFontSet fs));
-static int fontset_width __ARGS((XFontSet fs));
-static int fontset_ascent __ARGS((XFontSet fs));
+static int check_fontset_sanity(XFontSet fs);
+static int fontset_width(XFontSet fs);
+static int fontset_ascent(XFontSet fs);
 #endif
 
 static guicolor_T	prev_fg_color = INVALCOLOR;
@@ -136,26 +136,23 @@ static guicolor_T	prev_sp_color = INVALCOLOR;
 static XButtonPressedEvent last_mouse_event;
 #endif
 
-static int find_closest_color __ARGS((Colormap colormap, XColor *colorPtr));
-static void gui_x11_timer_cb __ARGS((XtPointer timed_out, XtIntervalId *interval_id));
-static void gui_x11_visibility_cb __ARGS((Widget w, XtPointer dud, XEvent *event, Boolean *dum));
-static void gui_x11_expose_cb __ARGS((Widget w, XtPointer dud, XEvent *event, Boolean *dum));
-static void gui_x11_resize_window_cb __ARGS((Widget w, XtPointer dud, XEvent *event, Boolean *dum));
-static void gui_x11_focus_change_cb __ARGS((Widget w, XtPointer data, XEvent *event, Boolean *dum));
-static void gui_x11_enter_cb __ARGS((Widget w, XtPointer data, XEvent *event, Boolean *dum));
-static void gui_x11_leave_cb __ARGS((Widget w, XtPointer data, XEvent *event, Boolean *dum));
-static void gui_x11_mouse_cb __ARGS((Widget w, XtPointer data, XEvent *event, Boolean *dum));
-#ifdef FEAT_SNIFF
-static void gui_x11_sniff_request_cb __ARGS((XtPointer closure, int *source, XtInputId *id));
-#endif
-static void gui_x11_check_copy_area __ARGS((void));
+static int find_closest_color(Colormap colormap, XColor *colorPtr);
+static void gui_x11_timer_cb(XtPointer timed_out, XtIntervalId *interval_id);
+static void gui_x11_visibility_cb(Widget w, XtPointer dud, XEvent *event, Boolean *dum);
+static void gui_x11_expose_cb(Widget w, XtPointer dud, XEvent *event, Boolean *dum);
+static void gui_x11_resize_window_cb(Widget w, XtPointer dud, XEvent *event, Boolean *dum);
+static void gui_x11_focus_change_cb(Widget w, XtPointer data, XEvent *event, Boolean *dum);
+static void gui_x11_enter_cb(Widget w, XtPointer data, XEvent *event, Boolean *dum);
+static void gui_x11_leave_cb(Widget w, XtPointer data, XEvent *event, Boolean *dum);
+static void gui_x11_mouse_cb(Widget w, XtPointer data, XEvent *event, Boolean *dum);
+static void gui_x11_check_copy_area(void);
 #ifdef FEAT_CLIENTSERVER
-static void gui_x11_send_event_handler __ARGS((Widget, XtPointer, XEvent *, Boolean *));
+static void gui_x11_send_event_handler(Widget, XtPointer, XEvent *, Boolean *);
 #endif
-static void gui_x11_wm_protocol_handler __ARGS((Widget, XtPointer, XEvent *, Boolean *));
-static void gui_x11_blink_cb __ARGS((XtPointer timed_out, XtIntervalId *interval_id));
-static Cursor gui_x11_create_blank_mouse __ARGS((void));
-static void draw_curl __ARGS((int row, int col, int cells));
+static void gui_x11_wm_protocol_handler(Widget, XtPointer, XEvent *, Boolean *);
+static void gui_x11_blink_cb(XtPointer timed_out, XtIntervalId *interval_id);
+static Cursor gui_x11_create_blank_mouse(void);
+static void draw_curl(int row, int col, int cells);
 
 
 /*
@@ -571,19 +568,19 @@ static char **gui_argv = NULL;
  */
 
     static void
-gui_x11_timer_cb(timed_out, interval_id)
-    XtPointer	    timed_out;
-    XtIntervalId    *interval_id UNUSED;
+gui_x11_timer_cb(
+    XtPointer	    timed_out,
+    XtIntervalId    *interval_id UNUSED)
 {
     *((int *)timed_out) = TRUE;
 }
 
     static void
-gui_x11_visibility_cb(w, dud, event, dum)
-    Widget	w UNUSED;
-    XtPointer	dud UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_visibility_cb(
+    Widget	w UNUSED,
+    XtPointer	dud UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     if (event->type != VisibilityNotify)
 	return;
@@ -602,11 +599,11 @@ gui_x11_visibility_cb(w, dud, event, dum)
 }
 
     static void
-gui_x11_expose_cb(w, dud, event, dum)
-    Widget	w UNUSED;
-    XtPointer	dud UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_expose_cb(
+    Widget	w UNUSED,
+    XtPointer	dud UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     XExposeEvent	*gevent;
     int			new_x;
@@ -678,11 +675,11 @@ shellRectangle(Widget shell, XRectangle *r)
 #endif
 
     static void
-gui_x11_resize_window_cb(w, dud, event, dum)
-    Widget	w UNUSED;
-    XtPointer	dud UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_resize_window_cb(
+    Widget	w UNUSED,
+    XtPointer	dud UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     static int lastWidth, lastHeight;
 
@@ -724,31 +721,31 @@ gui_x11_resize_window_cb(w, dud, event, dum)
 }
 
     static void
-gui_x11_focus_change_cb(w, data, event, dum)
-    Widget	w UNUSED;
-    XtPointer	data UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_focus_change_cb(
+    Widget	w UNUSED,
+    XtPointer	data UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     gui_focus_change(event->type == FocusIn);
 }
 
     static void
-gui_x11_enter_cb(w, data, event, dum)
-    Widget	w UNUSED;
-    XtPointer	data UNUSED;
-    XEvent	*event UNUSED;
-    Boolean	*dum UNUSED;
+gui_x11_enter_cb(
+    Widget	w UNUSED,
+    XtPointer	data UNUSED,
+    XEvent	*event UNUSED,
+    Boolean	*dum UNUSED)
 {
     gui_focus_change(TRUE);
 }
 
     static void
-gui_x11_leave_cb(w, data, event, dum)
-    Widget	w UNUSED;
-    XtPointer	data UNUSED;
-    XEvent	*event UNUSED;
-    Boolean	*dum UNUSED;
+gui_x11_leave_cb(
+    Widget	w UNUSED,
+    XtPointer	data UNUSED,
+    XEvent	*event UNUSED,
+    Boolean	*dum UNUSED)
 {
     gui_focus_change(FALSE);
 }
@@ -760,11 +757,11 @@ gui_x11_leave_cb(w, data, event, dum)
 #endif
 
     void
-gui_x11_key_hit_cb(w, dud, event, dum)
-    Widget	w UNUSED;
-    XtPointer	dud UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_key_hit_cb(
+    Widget	w UNUSED,
+    XtPointer	dud UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     XKeyPressedEvent	*ev_press;
 #ifdef FEAT_XIM
@@ -1071,11 +1068,11 @@ theend:
 }
 
     static void
-gui_x11_mouse_cb(w, dud, event, dum)
-    Widget	w UNUSED;
-    XtPointer	dud UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_mouse_cb(
+    Widget	w UNUSED,
+    XtPointer	dud UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     static XtIntervalId timer = (XtIntervalId)0;
     static int	timed_out = TRUE;
@@ -1127,11 +1124,16 @@ gui_x11_mouse_cb(w, dud, event, dum)
 			gui_x11_timer_cb, &timed_out);
 	    switch (event->xbutton.button)
 	    {
+		/* keep in sync with gui_gtk_x11.c */
 		case Button1:	button = MOUSE_LEFT;	break;
 		case Button2:	button = MOUSE_MIDDLE;	break;
 		case Button3:	button = MOUSE_RIGHT;	break;
 		case Button4:	button = MOUSE_4;	break;
 		case Button5:	button = MOUSE_5;	break;
+		case 6:		button = MOUSE_7;	break;
+		case 7:		button = MOUSE_6;	break;
+		case 8:		button = MOUSE_X1;	break;
+		case 9:		button = MOUSE_X2;	break;
 		default:
 		    return;	/* Unknown button */
 	    }
@@ -1158,20 +1160,6 @@ gui_x11_mouse_cb(w, dud, event, dum)
     gui_send_mouse_event(button, x, y, repeated_click, vim_modifiers);
 }
 
-#ifdef FEAT_SNIFF
-/* ARGSUSED */
-    static void
-gui_x11_sniff_request_cb(closure, source, id)
-    XtPointer	closure UNUSED;
-    int		*source UNUSED;
-    XtInputId	*id UNUSED;
-{
-    static char_u bytes[3] = {CSI, (int)KS_EXTRA, (int)KE_SNIFF};
-
-    add_to_input_buf(bytes, 3);
-}
-#endif
-
 /*
  * End of call-back routines
  */
@@ -1182,9 +1170,7 @@ gui_x11_sniff_request_cb(closure, source, id)
  * when vim is started, whether or not the GUI has been started.
  */
     void
-gui_mch_prepare(argc, argv)
-    int	    *argc;
-    char    **argv;
+gui_mch_prepare(int *argc, char **argv)
 {
     int	    arg;
     int	    i;
@@ -1280,7 +1266,7 @@ gui_mch_prepare(argc, argv)
  * Return OK or FAIL.
  */
     int
-gui_mch_init_check()
+gui_mch_init_check(void)
 {
 #ifdef FEAT_XIM
     XtSetLanguageProc(NULL, NULL, NULL);
@@ -1307,13 +1293,13 @@ gui_mch_init_check()
  */
 static XtInputId _xsmp_xtinputid;
 
-static void local_xsmp_handle_requests __ARGS((XtPointer c, int *s, XtInputId *i));
+static void local_xsmp_handle_requests(XtPointer c, int *s, XtInputId *i);
 
     static void
-local_xsmp_handle_requests(c, s, i)
-    XtPointer	c UNUSED;
-    int		*s UNUSED;
-    XtInputId	*i UNUSED;
+local_xsmp_handle_requests(
+    XtPointer	c UNUSED,
+    int		*s UNUSED,
+    XtInputId	*i UNUSED)
 {
     if (xsmp_handle_requests() == FAIL)
 	XtRemoveInput(_xsmp_xtinputid);
@@ -1326,7 +1312,7 @@ local_xsmp_handle_requests(c, s, i)
  * Returns OK for success, FAIL when the GUI can't be started.
  */
     int
-gui_mch_init()
+gui_mch_init(void)
 {
     XtGCMask	gc_mask;
     XGCValues	gc_vals;
@@ -1570,7 +1556,7 @@ gui_mch_init()
  * Called when starting the GUI fails after calling gui_mch_init().
  */
     void
-gui_mch_uninit()
+gui_mch_uninit(void)
 {
     gui_x11_destroy_widgets();
     XtCloseDisplay(gui.dpy);
@@ -1584,7 +1570,7 @@ gui_mch_uninit()
  * Called when the foreground or background color has been changed.
  */
     void
-gui_mch_new_colors()
+gui_mch_new_colors(void)
 {
     long_u	gc_mask;
     XGCValues	gc_vals;
@@ -1614,7 +1600,7 @@ gui_mch_new_colors()
  * Open the GUI window which was created by a call to gui_mch_init().
  */
     int
-gui_mch_open()
+gui_mch_open(void)
 {
     /* Actually open the window */
     XtRealizeWidget(vimShell);
@@ -1695,7 +1681,7 @@ gui_mch_open()
  * Convert the tooltip fontset name to an XFontSet.
  */
     void
-gui_init_tooltip_font()
+gui_init_tooltip_font(void)
 {
     XrmValue from, to;
 
@@ -1714,7 +1700,7 @@ gui_init_tooltip_font()
 #if defined(FEAT_MENU) || defined(PROTO)
 /* Convert the menu font/fontset name to an XFontStruct/XFontset */
     void
-gui_init_menu_font()
+gui_init_menu_font(void)
 {
     XrmValue from, to;
 
@@ -1743,8 +1729,7 @@ gui_init_menu_font()
 #endif
 
     void
-gui_mch_exit(rc)
-    int		rc UNUSED;
+gui_mch_exit(int rc UNUSED)
 {
 #if 0
     /* Lesstif gives an error message here, and so does Solaris.  The man page
@@ -1759,8 +1744,7 @@ gui_mch_exit(rc)
  * Get the position of the top left corner of the window.
  */
     int
-gui_mch_get_winpos(x, y)
-    int		*x, *y;
+gui_mch_get_winpos(int *x, int *y)
 {
     Dimension	xpos, ypos;
 
@@ -1778,8 +1762,7 @@ gui_mch_get_winpos(x, y)
  * coordinates.
  */
     void
-gui_mch_set_winpos(x, y)
-    int		x, y;
+gui_mch_set_winpos(int x, int y)
 {
     XtVaSetValues(vimShell,
 	XtNx,	x,
@@ -1788,15 +1771,14 @@ gui_mch_set_winpos(x, y)
 }
 
     void
-gui_mch_set_shellsize(width, height, min_width, min_height,
-		    base_width, base_height, direction)
-    int		width;
-    int		height;
-    int		min_width;
-    int		min_height;
-    int		base_width;
-    int		base_height;
-    int		direction UNUSED;
+gui_mch_set_shellsize(
+    int		width,
+    int		height,
+    int		min_width,
+    int		min_height,
+    int		base_width,
+    int		base_height,
+    int		direction UNUSED)
 {
 #ifdef FEAT_XIM
     height += xim_get_status_area_height(),
@@ -1820,9 +1802,9 @@ gui_mch_set_shellsize(width, height, min_width, min_height,
  * Is there no way in X to find out how wide the borders really are?
  */
     void
-gui_mch_get_screen_dimensions(screen_w, screen_h)
-    int	    *screen_w;
-    int	    *screen_h;
+gui_mch_get_screen_dimensions(
+    int	    *screen_w,
+    int	    *screen_h)
 {
     *screen_w = DisplayWidth(gui.dpy, DefaultScreen(gui.dpy)) - 10;
     *screen_h = DisplayHeight(gui.dpy, DefaultScreen(gui.dpy)) - p_ghr;
@@ -1835,9 +1817,9 @@ gui_mch_get_screen_dimensions(screen_w, screen_h)
  * Return FAIL if the font could not be loaded, OK otherwise.
  */
     int
-gui_mch_init_font(font_name, do_fontset)
-    char_u	*font_name;
-    int		do_fontset UNUSED;
+gui_mch_init_font(
+    char_u	*font_name,
+    int		do_fontset UNUSED)
 {
     XFontStruct	*font = NULL;
 
@@ -1965,9 +1947,7 @@ gui_mch_init_font(font_name, do_fontset)
  * Get a font structure for highlighting.
  */
     GuiFont
-gui_mch_get_font(name, giveErrorIfMissing)
-    char_u	*name;
-    int		giveErrorIfMissing;
+gui_mch_get_font(char_u *name, int giveErrorIfMissing)
 {
     XFontStruct	*font;
 
@@ -2016,9 +1996,7 @@ gui_mch_get_font(name, giveErrorIfMissing)
  * Don't know how to get the actual name, thus use the provided name.
  */
     char_u *
-gui_mch_get_fontname(font, name)
-    GuiFont font UNUSED;
-    char_u  *name;
+gui_mch_get_fontname(GuiFont font UNUSED, char_u *name)
 {
     if (name == NULL)
 	return NULL;
@@ -2030,7 +2008,7 @@ gui_mch_get_fontname(font, name)
  * Adjust gui.char_height (after 'linespace' was changed).
  */
     int
-gui_mch_adjust_charheight()
+gui_mch_adjust_charheight(void)
 {
 #ifdef FEAT_XFONTSET
     if (gui.fontset != NOFONTSET)
@@ -2054,8 +2032,7 @@ gui_mch_adjust_charheight()
  * Set the current text font.
  */
     void
-gui_mch_set_font(font)
-    GuiFont	font;
+gui_mch_set_font(GuiFont font)
 {
     static Font	prev_font = (Font)-1;
     Font	fid = ((XFontStruct *)font)->fid;
@@ -2078,8 +2055,7 @@ gui_mch_set_font(font)
  * Adjust the ascent, in case it's different.
  */
     void
-gui_mch_set_fontset(fontset)
-    GuiFontset	fontset;
+gui_mch_set_fontset(GuiFontset fontset)
 {
     current_fontset = (XFontSet)fontset;
     gui.char_ascent = fontset_ascent(current_fontset) + p_linespace / 2;
@@ -2090,8 +2066,7 @@ gui_mch_set_fontset(fontset)
  * If a font is not going to be used, free its structure.
  */
     void
-gui_mch_free_font(font)
-    GuiFont	font;
+gui_mch_free_font(GuiFont font)
 {
     if (font != NOFONT)
 	XFreeFont(gui.dpy, (XFontStruct *)font);
@@ -2102,8 +2077,7 @@ gui_mch_free_font(font)
  * If a fontset is not going to be used, free its structure.
  */
     void
-gui_mch_free_fontset(fontset)
-    GuiFontset	fontset;
+gui_mch_free_fontset(GuiFontset fontset)
 {
     if (fontset != NOFONTSET)
 	XFreeFontSet(gui.dpy, (XFontSet)fontset);
@@ -2114,10 +2088,10 @@ gui_mch_free_fontset(fontset)
  * Return a reference to the fontset, or NOFONTSET when failing.
  */
     GuiFontset
-gui_mch_get_fontset(name, giveErrorIfMissing, fixed_width)
-    char_u	*name;
-    int		giveErrorIfMissing;
-    int		fixed_width;
+gui_mch_get_fontset(
+    char_u	*name,
+    int		giveErrorIfMissing,
+    int		fixed_width)
 {
     XFontSet	fontset;
     char	**missing, *def_str;
@@ -2160,8 +2134,7 @@ gui_mch_get_fontset(name, giveErrorIfMissing, fixed_width)
  * Check if fontset "fs" is fixed width.
  */
     static int
-check_fontset_sanity(fs)
-    XFontSet fs;
+check_fontset_sanity(XFontSet fs)
 {
     XFontStruct	**xfs;
     char	**font_name;
@@ -2211,15 +2184,14 @@ check_fontset_sanity(fs)
 }
 
     static int
-fontset_width(fs)
-    XFontSet fs;
+fontset_width(XFontSet fs)
 {
-    return XmbTextEscapement(fs, "Vim", 3) / 3;
+ return XmbTextEscapement(fs, "Vim", 3) / 3;
 }
 
     int
-fontset_height(fs)
-    XFontSet fs;
+fontset_height(
+    XFontSet fs)
 {
     XFontSetExtents *extents;
 
@@ -2234,8 +2206,7 @@ fontset_height(fs)
  * characters in all fonts of the fontset.
  */
     int
-fontset_height2(fs)
-    XFontSet fs;
+fontset_height2(XFontSet fs)
 {
     XFontSetExtents *extents;
 
@@ -2246,8 +2217,7 @@ fontset_height2(fs)
 
 /* NOT USED YET
     static int
-fontset_descent(fs)
-    XFontSet fs;
+fontset_descent(XFontSet fs)
 {
     XFontSetExtents *extents;
 
@@ -2257,8 +2227,7 @@ fontset_descent(fs)
 */
 
     static int
-fontset_ascent(fs)
-    XFontSet fs;
+fontset_ascent(XFontSet fs)
 {
     XFontSetExtents *extents;
 
@@ -2273,8 +2242,7 @@ fontset_ascent(fs)
  * Return INVALCOLOR for error.
  */
     guicolor_T
-gui_mch_get_color(reqname)
-    char_u *reqname;
+gui_mch_get_color(char_u *reqname)
 {
     int		i;
     char_u	*name = reqname;
@@ -2377,9 +2345,7 @@ gui_mch_get_color(reqname)
  * Return FAIL if not able to find or allocate a color.
  */
     static int
-find_closest_color(colormap, colorPtr)
-    Colormap	colormap;
-    XColor	*colorPtr;
+find_closest_color(Colormap colormap, XColor *colorPtr)
 {
     double	tmp, distance, closestDistance;
     int		i, closest, numFound, cmap_size;
@@ -2447,8 +2413,7 @@ find_closest_color(colormap, colorPtr)
  * Set the current text foreground color.
  */
     void
-gui_mch_set_fg_color(color)
-    guicolor_T	color;
+gui_mch_set_fg_color(guicolor_T color)
 {
     if (color != prev_fg_color)
     {
@@ -2461,8 +2426,7 @@ gui_mch_set_fg_color(color)
  * Set the current text background color.
  */
     void
-gui_mch_set_bg_color(color)
-    guicolor_T	color;
+gui_mch_set_bg_color(guicolor_T color)
 {
     if (color != prev_bg_color)
     {
@@ -2475,8 +2439,7 @@ gui_mch_set_bg_color(color)
  * Set the current text special color.
  */
     void
-gui_mch_set_sp_color(color)
-    guicolor_T	color;
+gui_mch_set_sp_color(guicolor_T color)
 {
     prev_sp_color = color;
 }
@@ -2485,7 +2448,7 @@ gui_mch_set_sp_color(color)
  * create a mouse pointer that is blank
  */
     static Cursor
-gui_x11_create_blank_mouse()
+gui_x11_create_blank_mouse(void)
 {
     Pixmap blank_pixmap = XCreatePixmap(gui.dpy, gui.wid, 1, 1, 1);
     GC gc = XCreateGC(gui.dpy, blank_pixmap, (unsigned long)0, (XGCValues*)0);
@@ -2499,10 +2462,7 @@ gui_x11_create_blank_mouse()
  * Draw a curled line at the bottom of the character cell.
  */
     static void
-draw_curl(row, col, cells)
-    int row;
-    int col;
-    int cells;
+draw_curl(int row, int col, int cells)
 {
     int			i;
     int			offset;
@@ -2519,12 +2479,12 @@ draw_curl(row, col, cells)
 }
 
     void
-gui_mch_draw_string(row, col, s, len, flags)
-    int		row;
-    int		col;
-    char_u	*s;
-    int		len;
-    int		flags;
+gui_mch_draw_string(
+    int		row,
+    int		col,
+    char_u	*s,
+    int		len,
+    int		flags)
 {
     int			cells = len;
 #ifdef FEAT_MBYTE
@@ -2686,8 +2646,7 @@ gui_mch_draw_string(row, col, s, len, flags)
  * Return OK if the key with the termcap name "name" is supported.
  */
     int
-gui_mch_haskey(name)
-    char_u  *name;
+gui_mch_haskey(char_u *name)
 {
     int i;
 
@@ -2702,9 +2661,7 @@ gui_mch_haskey(name)
  * Return the text window-id and display.  Only required for X-based GUI's
  */
     int
-gui_get_x11_windis(win, dis)
-    Window  *win;
-    Display **dis;
+gui_get_x11_windis(Window *win, Display **dis)
 {
     *win = XtWindow(vimShell);
     *dis = gui.dpy;
@@ -2712,14 +2669,13 @@ gui_get_x11_windis(win, dis)
 }
 
     void
-gui_mch_beep()
+gui_mch_beep(void)
 {
     XBell(gui.dpy, 0);
 }
 
     void
-gui_mch_flash(msec)
-    int		msec;
+gui_mch_flash(int msec)
 {
     /* Do a visual beep by reversing the foreground and background colors */
     XFillRectangle(gui.dpy, gui.wid, gui.invert_gc, 0, 0,
@@ -2736,11 +2692,11 @@ gui_mch_flash(msec)
  * Invert a rectangle from row r, column c, for nr rows and nc columns.
  */
     void
-gui_mch_invert_rectangle(r, c, nr, nc)
-    int	    r;
-    int	    c;
-    int	    nr;
-    int	    nc;
+gui_mch_invert_rectangle(
+    int	    r,
+    int	    c,
+    int	    nr,
+    int	    nc)
 {
     XFillRectangle(gui.dpy, gui.wid, gui.invert_gc,
 	FILL_X(c), FILL_Y(r), (nc) * gui.char_width, (nr) * gui.char_height);
@@ -2750,7 +2706,7 @@ gui_mch_invert_rectangle(r, c, nr, nc)
  * Iconify the GUI window.
  */
     void
-gui_mch_iconify()
+gui_mch_iconify(void)
 {
     XIconifyWindow(gui.dpy, XtWindow(vimShell), DefaultScreen(gui.dpy));
 }
@@ -2760,7 +2716,7 @@ gui_mch_iconify()
  * Bring the Vim window to the foreground.
  */
     void
-gui_mch_set_foreground()
+gui_mch_set_foreground(void)
 {
     XMapRaised(gui.dpy, XtWindow(vimShell));
 }
@@ -2770,8 +2726,7 @@ gui_mch_set_foreground()
  * Draw a cursor without focus.
  */
     void
-gui_mch_draw_hollow_cursor(color)
-    guicolor_T color;
+gui_mch_draw_hollow_cursor(guicolor_T color)
 {
     int		w = 1;
 
@@ -2789,10 +2744,7 @@ gui_mch_draw_hollow_cursor(color)
  * color "color".
  */
     void
-gui_mch_draw_part_cursor(w, h, color)
-    int		w;
-    int		h;
-    guicolor_T	color;
+gui_mch_draw_part_cursor(int w, int h, guicolor_T color)
 {
     gui_mch_set_fg_color(color);
 
@@ -2813,7 +2765,7 @@ gui_mch_draw_part_cursor(w, h, color)
  * immediately.
  */
     void
-gui_mch_update()
+gui_mch_update(void)
 {
     XtInputMask mask, desired;
 
@@ -2838,8 +2790,7 @@ gui_mch_update()
  * or FAIL otherwise.
  */
     int
-gui_mch_wait_for_chars(wtime)
-    long    wtime;
+gui_mch_wait_for_chars(long wtime)
 {
     int		    focus;
 
@@ -2850,28 +2801,9 @@ gui_mch_wait_for_chars(wtime)
     static int	    timed_out;
     XtIntervalId    timer = (XtIntervalId)0;
     XtInputMask	    desired;
-#ifdef FEAT_SNIFF
-    static int	    sniff_on = 0;
-    static XtInputId sniff_input_id = 0;
-#endif
 
     timed_out = FALSE;
 
-#ifdef FEAT_SNIFF
-    if (sniff_on && !want_sniff_request)
-    {
-	if (sniff_input_id)
-	    XtRemoveInput(sniff_input_id);
-	sniff_on = 0;
-    }
-    else if (!sniff_on && want_sniff_request)
-    {
-	sniff_input_id = XtAppAddInput(app_context, fd_from_sniff,
-		     (XtPointer)XtInputReadMask, gui_x11_sniff_request_cb, 0);
-	sniff_on = 1;
-    }
-#endif
-
     if (wtime > 0)
 	timer = XtAppAddTimeOut(app_context, (long_u)wtime, gui_x11_timer_cb,
 								  &timed_out);
@@ -2925,7 +2857,7 @@ gui_mch_wait_for_chars(wtime)
 
 /* Flush any output to the screen */
     void
-gui_mch_flush()
+gui_mch_flush(void)
 {
     XFlush(gui.dpy);
 }
@@ -2935,11 +2867,11 @@ gui_mch_flush()
  * (row2, col2) inclusive.
  */
     void
-gui_mch_clear_block(row1, col1, row2, col2)
-    int		row1;
-    int		col1;
-    int		row2;
-    int		col2;
+gui_mch_clear_block(
+    int		row1,
+    int		col1,
+    int		row2,
+    int		col2)
 {
     int		x;
 
@@ -2953,7 +2885,7 @@ gui_mch_clear_block(row1, col1, row2, col2)
 }
 
     void
-gui_mch_clear_all()
+gui_mch_clear_all(void)
 {
     XClearArea(gui.dpy, gui.wid, 0, 0, 0, 0, False);
 }
@@ -2963,9 +2895,7 @@ gui_mch_clear_all()
  * text further down within the scroll region.
  */
     void
-gui_mch_delete_lines(row, num_lines)
-    int	    row;
-    int	    num_lines;
+gui_mch_delete_lines(int row, int num_lines)
 {
     if (gui.visibility == VisibilityFullyObscured)
 	return;	    /* Can't see the window */
@@ -2990,9 +2920,7 @@ gui_mch_delete_lines(row, num_lines)
  * following text within the scroll region.
  */
     void
-gui_mch_insert_lines(row, num_lines)
-    int	    row;
-    int	    num_lines;
+gui_mch_insert_lines(int row, int num_lines)
 {
     if (gui.visibility == VisibilityFullyObscured)
 	return;	    /* Can't see the window */
@@ -3015,7 +2943,7 @@ gui_mch_insert_lines(row, num_lines)
  * Update the region revealed by scrolling up/down.
  */
     static void
-gui_x11_check_copy_area()
+gui_x11_check_copy_area(void)
 {
     XEvent		    event;
     XGraphicsExposeEvent    *gevent;
@@ -3047,29 +2975,26 @@ gui_x11_check_copy_area()
  */
 
     void
-clip_mch_lose_selection(cbd)
-    VimClipboard	*cbd;
+clip_mch_lose_selection(VimClipboard *cbd)
 {
     clip_x11_lose_selection(vimShell, cbd);
 }
 
     int
-clip_mch_own_selection(cbd)
-    VimClipboard	*cbd;
+clip_mch_own_selection(VimClipboard *cbd)
 {
     return clip_x11_own_selection(vimShell, cbd);
 }
 
     void
-clip_mch_request_selection(cbd)
-    VimClipboard	*cbd;
+clip_mch_request_selection(VimClipboard *cbd)
 {
-    clip_x11_request_selection(vimShell, gui.dpy, cbd);
+ clip_x11_request_selection(vimShell, gui.dpy, cbd);
 }
 
     void
-clip_mch_set_selection(cbd)
-    VimClipboard	*cbd;
+clip_mch_set_selection(
+    VimClipboard	*cbd)
 {
     clip_x11_set_selection(cbd);
 }
@@ -3083,9 +3008,7 @@ clip_mch_set_selection(cbd)
  * Make a menu either grey or not grey.
  */
     void
-gui_mch_menu_grey(menu, grey)
-    vimmenu_T	*menu;
-    int		grey;
+gui_mch_menu_grey(vimmenu_T *menu, int grey)
 {
     if (menu->id != (Widget)0)
     {
@@ -3105,9 +3028,7 @@ gui_mch_menu_grey(menu, grey)
  * Make menu item hidden or not hidden
  */
     void
-gui_mch_menu_hidden(menu, hidden)
-    vimmenu_T	*menu;
-    int		hidden;
+gui_mch_menu_hidden(vimmenu_T *menu, int hidden)
 {
     if (menu->id != (Widget)0)
     {
@@ -3122,16 +3043,16 @@ gui_mch_menu_hidden(menu, hidden)
  * This is called after setting all the menus to grey/hidden or not.
  */
     void
-gui_mch_draw_menubar()
+gui_mch_draw_menubar(void)
 {
     /* Nothing to do in X */
 }
 
     void
-gui_x11_menu_cb(w, client_data, call_data)
-    Widget	w UNUSED;
-    XtPointer	client_data;
-    XtPointer	call_data UNUSED;
+gui_x11_menu_cb(
+    Widget	w UNUSED,
+    XtPointer	client_data,
+    XtPointer	call_data UNUSED)
 {
     gui_menu_cb((vimmenu_T *)client_data);
 }
@@ -3145,11 +3066,11 @@ gui_x11_menu_cb(w, client_data, call_data)
  * Should put up a requester!
  */
     static void
-gui_x11_wm_protocol_handler(w, client_data, event, dum)
-    Widget	w UNUSED;
-    XtPointer	client_data UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_wm_protocol_handler(
+    Widget	w UNUSED,
+    XtPointer	client_data UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     /*
      * Only deal with Client messages.
@@ -3187,11 +3108,11 @@ gui_x11_wm_protocol_handler(w, client_data, event, dum)
  * Function called when property changed. Check for incoming commands
  */
     static void
-gui_x11_send_event_handler(w, client_data, event, dum)
-    Widget	w UNUSED;
-    XtPointer	client_data UNUSED;
-    XEvent	*event;
-    Boolean	*dum UNUSED;
+gui_x11_send_event_handler(
+    Widget	w UNUSED,
+    XtPointer	client_data UNUSED,
+    XEvent	*event,
+    Boolean	*dum UNUSED)
 {
     XPropertyEvent *e = (XPropertyEvent *) event;
 
@@ -3223,8 +3144,7 @@ static long_u		blink_offtime = 250;
 static XtIntervalId	blink_timer = (XtIntervalId)0;
 
     void
-gui_mch_set_blinking(waittime, on, off)
-    long    waittime, on, off;
+gui_mch_set_blinking(long waittime, long on, long off)
 {
     blink_waittime = waittime;
     blink_ontime = on;
@@ -3235,7 +3155,7 @@ gui_mch_set_blinking(waittime, on, off)
  * Stop the cursor blinking.  Show the cursor if it wasn't shown.
  */
     void
-gui_mch_stop_blink()
+gui_mch_stop_blink(void)
 {
     if (blink_timer != (XtIntervalId)0)
     {
@@ -3252,7 +3172,7 @@ gui_mch_stop_blink()
  * waiting time and shows the cursor.
  */
     void
-gui_mch_start_blink()
+gui_mch_start_blink(void)
 {
     if (blink_timer != (XtIntervalId)0)
 	XtRemoveTimeOut(blink_timer);
@@ -3267,9 +3187,9 @@ gui_mch_start_blink()
 }
 
     static void
-gui_x11_blink_cb(timed_out, interval_id)
-    XtPointer	    timed_out UNUSED;
-    XtIntervalId    *interval_id UNUSED;
+gui_x11_blink_cb(
+    XtPointer	    timed_out UNUSED,
+    XtIntervalId    *interval_id UNUSED)
 {
     if (blink_state == BLINK_ON)
     {
@@ -3291,8 +3211,7 @@ gui_x11_blink_cb(timed_out, interval_id)
  * Return the RGB value of a pixel as a long.
  */
     long_u
-gui_mch_get_rgb(pixel)
-    guicolor_T	pixel;
+gui_mch_get_rgb(guicolor_T pixel)
 {
     XColor	xc;
     Colormap	colormap;
@@ -3309,9 +3228,7 @@ gui_mch_get_rgb(pixel)
  * Add the callback functions.
  */
     void
-gui_x11_callbacks(textArea, vimForm)
-    Widget textArea;
-    Widget vimForm;
+gui_x11_callbacks(Widget textArea, Widget vimForm)
 {
     XtAddEventHandler(textArea, VisibilityChangeMask, FALSE,
 	gui_x11_visibility_cb, (XtPointer)0);
@@ -3374,9 +3291,7 @@ gui_mch_getmouse(int *x, int *y)
 }
 
     void
-gui_mch_setmouse(x, y)
-    int		x;
-    int		y;
+gui_mch_setmouse(int x, int y)
 {
     if (gui.wid)
 	XWarpPointer(gui.dpy, (Window)0, gui.wid, 0, 0, 0, 0, x, y);
@@ -3384,7 +3299,7 @@ gui_mch_setmouse(x, y)
 
 #if (defined(FEAT_GUI_MOTIF) && defined(FEAT_MENU)) || defined(PROTO)
     XButtonPressedEvent *
-gui_x11_get_last_mouse_event()
+gui_x11_get_last_mouse_event(void)
 {
     return &last_mouse_event;
 }
@@ -3397,10 +3312,7 @@ gui_x11_get_last_mouse_event()
 # define SIGN_WIDTH (gui.char_width * 2)
 
     void
-gui_mch_drawsign(row, col, typenr)
-    int		row;
-    int		col;
-    int		typenr;
+gui_mch_drawsign(int row, int col, int typenr)
 {
     XImage	*sign;
 
@@ -3416,8 +3328,7 @@ gui_mch_drawsign(row, col, typenr)
 }
 
     void *
-gui_mch_register_sign(signfile)
-    char_u	    *signfile;
+gui_mch_register_sign(char_u *signfile)
 {
     XpmAttributes   attrs;
     XImage	    *sign = NULL;
@@ -3457,8 +3368,7 @@ gui_mch_register_sign(signfile)
 }
 
     void
-gui_mch_destroy_sign(sign)
-    void *sign;
+gui_mch_destroy_sign(void *sign)
 {
     XDestroyImage((XImage*)sign);
 }
@@ -3475,8 +3385,8 @@ static int last_shape = 0;
  * Use the blank mouse pointer or not.
  */
     void
-gui_mch_mousehide(hide)
-    int		hide;	/* TRUE = use blank ptr, FALSE = use parent ptr */
+gui_mch_mousehide(
+    int		hide)	/* TRUE = use blank ptr, FALSE = use parent ptr */
 {
     if (gui.pointer_hidden != hide)
     {
@@ -3518,8 +3428,7 @@ static int mshape_ids[] =
 };
 
     void
-mch_set_mouse_shape(shape)
-    int	shape;
+mch_set_mouse_shape(int shape)
 {
     int	    id;
 
@@ -3555,8 +3464,7 @@ mch_set_mouse_shape(shape)
  * passing a normal menu item here.  Can't explain that, but better avoid it.
  */
     void
-gui_mch_menu_set_tip(menu)
-    vimmenu_T	*menu;
+gui_mch_menu_set_tip(vimmenu_T *menu)
 {
     if (menu->id != NULL && menu->parent != NULL
 				       && menu_is_toolbar(menu->parent->name))
