@@ -20,43 +20,43 @@
 #endif
 #include "if_cscope.h"
 
-static void	    cs_usage_msg __ARGS((csid_e x));
-static int	    cs_add __ARGS((exarg_T *eap));
-static void	    cs_stat_emsg __ARGS((char *fname));
-static int	    cs_add_common __ARGS((char *, char *, char *));
-static int	    cs_check_for_connections __ARGS((void));
-static int	    cs_check_for_tags __ARGS((void));
-static int	    cs_cnt_connections __ARGS((void));
-static void	    cs_reading_emsg __ARGS((int idx));
-static int	    cs_cnt_matches __ARGS((int idx));
-static char *	    cs_create_cmd __ARGS((char *csoption, char *pattern));
-static int	    cs_create_connection __ARGS((int i));
-static void	    do_cscope_general __ARGS((exarg_T *eap, int make_split));
+static void	    cs_usage_msg(csid_e x);
+static int	    cs_add(exarg_T *eap);
+static void	    cs_stat_emsg(char *fname);
+static int	    cs_add_common(char *, char *, char *);
+static int	    cs_check_for_connections(void);
+static int	    cs_check_for_tags(void);
+static int	    cs_cnt_connections(void);
+static void	    cs_reading_emsg(int idx);
+static int	    cs_cnt_matches(int idx);
+static char *	    cs_create_cmd(char *csoption, char *pattern);
+static int	    cs_create_connection(int i);
+static void	    do_cscope_general(exarg_T *eap, int make_split);
 #ifdef FEAT_QUICKFIX
-static void	    cs_file_results __ARGS((FILE *, int *));
+static void	    cs_file_results(FILE *, int *);
 #endif
-static void	    cs_fill_results __ARGS((char *, int , int *, char ***,
-			char ***, int *));
-static int	    cs_find __ARGS((exarg_T *eap));
-static int	    cs_find_common __ARGS((char *opt, char *pat, int, int, int, char_u *cmdline));
-static int	    cs_help __ARGS((exarg_T *eap));
-static void	    clear_csinfo __ARGS((int i));
-static int	    cs_insert_filelist __ARGS((char *, char *, char *,
-			struct stat *));
-static int	    cs_kill __ARGS((exarg_T *eap));
-static void	    cs_kill_execute __ARGS((int, char *));
-static cscmd_T *    cs_lookup_cmd __ARGS((exarg_T *eap));
-static char *	    cs_make_vim_style_matches __ARGS((char *, char *,
-			char *, char *));
-static char *	    cs_manage_matches __ARGS((char **, char **, int, mcmd_e));
-static char *	    cs_parse_results __ARGS((int cnumber, char *buf, int bufsize, char **context, char **linenumber, char **search));
-static char *	    cs_pathcomponents __ARGS((char *path));
-static void	    cs_print_tags_priv __ARGS((char **, char **, int));
-static int	    cs_read_prompt __ARGS((int));
-static void	    cs_release_csp __ARGS((int, int freefnpp));
-static int	    cs_reset __ARGS((exarg_T *eap));
-static char *	    cs_resolve_file __ARGS((int, char *));
-static int	    cs_show __ARGS((exarg_T *eap));
+static void	    cs_fill_results(char *, int , int *, char ***,
+			char ***, int *);
+static int	    cs_find(exarg_T *eap);
+static int	    cs_find_common(char *opt, char *pat, int, int, int, char_u *cmdline);
+static int	    cs_help(exarg_T *eap);
+static void	    clear_csinfo(int i);
+static int	    cs_insert_filelist(char *, char *, char *,
+			struct stat *);
+static int	    cs_kill(exarg_T *eap);
+static void	    cs_kill_execute(int, char *);
+static cscmd_T *    cs_lookup_cmd(exarg_T *eap);
+static char *	    cs_make_vim_style_matches(char *, char *,
+			char *, char *);
+static char *	    cs_manage_matches(char **, char **, int, mcmd_e);
+static char *	    cs_parse_results(int cnumber, char *buf, int bufsize, char **context, char **linenumber, char **search);
+static char *	    cs_pathcomponents(char *path);
+static void	    cs_print_tags_priv(char **, char **, int);
+static int	    cs_read_prompt(int);
+static void	    cs_release_csp(int, int freefnpp);
+static int	    cs_reset(exarg_T *eap);
+static char *	    cs_resolve_file(int, char *);
+static int	    cs_show(exarg_T *eap);
 
 
 static csinfo_T *   csinfo = NULL;
@@ -83,8 +83,7 @@ static cscmd_T	    cs_cmds[] =
 };
 
     static void
-cs_usage_msg(x)
-    csid_e x;
+cs_usage_msg(csid_e x)
 {
     (void)EMSG2(_("E560: Usage: cs[cope] %s"), cs_cmds[(int)x].usage);
 }
@@ -104,9 +103,7 @@ static enum
  * expansion.
  */
     char_u *
-get_cscope_name(xp, idx)
-    expand_T	*xp UNUSED;
-    int		idx;
+get_cscope_name(expand_T *xp UNUSED, int idx)
 {
     int		current_idx;
     int		i;
@@ -167,10 +164,10 @@ get_cscope_name(xp, idx)
  * Handle command line completion for :cscope command.
  */
     void
-set_context_in_cscope_cmd(xp, arg, cmdidx)
-    expand_T	*xp;
-    char_u	*arg;
-    cmdidx_T	cmdidx;
+set_context_in_cscope_cmd(
+    expand_T	*xp,
+    char_u	*arg,
+    cmdidx_T	cmdidx)
 {
     char_u	*p;
 
@@ -210,9 +207,9 @@ set_context_in_cscope_cmd(xp, arg, cmdidx)
  * command function.
  */
     static void
-do_cscope_general(eap, make_split)
-    exarg_T	*eap;
-    int		make_split; /* whether to split window */
+do_cscope_general(
+    exarg_T	*eap,
+    int		make_split) /* whether to split window */
 {
     cscmd_T *cmdp;
 
@@ -248,8 +245,7 @@ do_cscope_general(eap, make_split)
  * PUBLIC: do_cscope
  */
     void
-do_cscope(eap)
-    exarg_T *eap;
+do_cscope(exarg_T *eap)
 {
     do_cscope_general(eap, FALSE);
 }
@@ -260,8 +256,7 @@ do_cscope(eap)
  * same as do_cscope, but splits window, too.
  */
     void
-do_scscope(eap)
-    exarg_T *eap;
+do_scscope(exarg_T *eap)
 {
     do_cscope_general(eap, TRUE);
 }
@@ -271,8 +266,7 @@ do_scscope(eap)
  *
  */
     void
-do_cstag(eap)
-    exarg_T *eap;
+do_cstag(exarg_T *eap)
 {
     int ret = FALSE;
 
@@ -354,9 +348,7 @@ do_cstag(eap)
  * returns TRUE if eof, FALSE otherwise
  */
     int
-cs_fgets(buf, size)
-    char_u	*buf;
-    int		size;
+cs_fgets(char_u *buf, int size)
 {
     char *p;
 
@@ -374,7 +366,7 @@ cs_fgets(buf, size)
  * called only from do_tag(), when popping the tag stack
  */
     void
-cs_free_tags()
+cs_free_tags(void)
 {
     cs_manage_matches(NULL, NULL, -1, Free);
 }
@@ -386,7 +378,7 @@ cs_free_tags()
  * called from do_tag()
  */
     void
-cs_print_tags()
+cs_print_tags(void)
 {
     cs_manage_matches(NULL, NULL, -1, Print);
 }
@@ -421,10 +413,7 @@ cs_print_tags()
  */
 #if defined(FEAT_EVAL) || defined(PROTO)
     int
-cs_connection(num, dbpath, ppath)
-    int num;
-    char_u *dbpath;
-    char_u *ppath;
+cs_connection(int num, char_u *dbpath, char_u *ppath)
 {
     int i;
 
@@ -486,8 +475,7 @@ cs_connection(num, dbpath, ppath)
  * MAXPATHL 256
  */
     static int
-cs_add(eap)
-    exarg_T *eap UNUSED;
+cs_add(exarg_T *eap UNUSED)
 {
     char *fname, *ppath, *flags = NULL;
 
@@ -503,8 +491,7 @@ cs_add(eap)
 }
 
     static void
-cs_stat_emsg(fname)
-    char *fname;
+cs_stat_emsg(char *fname)
 {
     char *stat_emsg = _("E563: stat(%s) error: %d");
     char *buf = (char *)alloc((unsigned)strlen(stat_emsg) + MAXPATHL + 10);
@@ -528,10 +515,10 @@ cs_stat_emsg(fname)
  * routine uses a number of goto statements.
  */
     static int
-cs_add_common(arg1, arg2, flags)
-    char *arg1;	    /* filename - may contain environment variables */
-    char *arg2;	    /* prepend path - may contain environment variables */
-    char *flags;
+cs_add_common(
+    char *arg1,	    /* filename - may contain environment variables */
+    char *arg2,	    /* prepend path - may contain environment variables */
+    char *flags)
 {
     struct stat statbuf;
     int		ret;
@@ -539,12 +526,27 @@ cs_add_common(arg1, arg2, flags)
     char	*fname2 = NULL;
     char	*ppath = NULL;
     int		i;
+#ifdef FEAT_MODIFY_FNAME
+    int		len;
+    int		usedlen = 0;
+    char_u	*fbuf = NULL;
+#endif
 
     /* get the filename (arg1), expand it, and try to stat it */
     if ((fname = (char *)alloc(MAXPATHL + 1)) == NULL)
 	goto add_err;
 
     expand_env((char_u *)arg1, (char_u *)fname, MAXPATHL);
+#ifdef FEAT_MODIFY_FNAME
+    len = (int)STRLEN(fname);
+    fbuf = (char_u *)fname;
+    (void)modify_fname((char_u *)":p", &usedlen,
+					      (char_u **)&fname, &fbuf, &len);
+    if (fname == NULL)
+	goto add_err;
+    fname = (char *)vim_strnsave((char_u *)fname, len);
+    vim_free(fbuf);
+#endif
     ret = stat(fname, &statbuf);
     if (ret < 0)
     {
@@ -650,14 +652,14 @@ add_err:
 
 
     static int
-cs_check_for_connections()
+cs_check_for_connections(void)
 {
     return (cs_cnt_connections() > 0);
 } /* cs_check_for_connections */
 
 
     static int
-cs_check_for_tags()
+cs_check_for_tags(void)
 {
     return (p_tags[0] != NUL && curbuf->b_p_tags != NULL);
 } /* cs_check_for_tags */
@@ -669,7 +671,7 @@ cs_check_for_tags()
  * count the number of cscope connections
  */
     static int
-cs_cnt_connections()
+cs_cnt_connections(void)
 {
     short i;
     short cnt = 0;
@@ -683,8 +685,8 @@ cs_cnt_connections()
 } /* cs_cnt_connections */
 
     static void
-cs_reading_emsg(idx)
-    int idx;	/* connection index */
+cs_reading_emsg(
+    int idx)	/* connection index */
 {
     EMSGN(_("E262: error reading cscope connection %ld"), idx);
 }
@@ -696,8 +698,7 @@ cs_reading_emsg(idx)
  * count the number of matches for a given cscope connection.
  */
     static int
-cs_cnt_matches(idx)
-    int idx;
+cs_cnt_matches(int idx)
 {
     char *stok;
     char *buf;
@@ -758,9 +759,7 @@ cs_cnt_matches(idx)
  * Creates the actual cscope command query from what the user entered.
  */
     static char *
-cs_create_cmd(csoption, pattern)
-    char *csoption;
-    char *pattern;
+cs_create_cmd(char *csoption, char *pattern)
 {
     char *cmd;
     short search;
@@ -821,8 +820,7 @@ cs_create_cmd(csoption, pattern)
  * the BSD license notice?
  */
     static int
-cs_create_connection(i)
-    int i;
+cs_create_connection(int i)
 {
 #ifdef UNIX
     int		to_cs[2], from_cs[2];
@@ -841,7 +839,7 @@ cs_create_connection(i)
 # ifdef __BORLANDC__
 #  define OPEN_OH_ARGTYPE long
 # else
-#  if (_MSC_VER >= 1300)
+#  if (_MSC_VER >= 1300) || defined(__MINGW32__)
 #   define OPEN_OH_ARGTYPE intptr_t
 #  else
 #   define OPEN_OH_ARGTYPE long
@@ -982,6 +980,15 @@ err_closing:
 	vim_free(ppath);
 
 #if defined(UNIX)
+# if defined(HAVE_SETSID) || defined(HAVE_SETPGID)
+	/* Change our process group to avoid cscope receiving SIGWINCH. */
+#  if defined(HAVE_SETSID)
+	(void)setsid();
+#  else
+	if (setpgid(0, 0) == -1)
+	    PERROR(_("cs_create_connection setpgid failed"));
+#  endif
+# endif
 	if (execl("/bin/sh", "sh", "-c", cmd, (char *)NULL) == -1)
 	    PERROR(_("cs_create_connection exec failed"));
 
@@ -1052,14 +1059,13 @@ err_closing:
 /*
  * PRIVATE: cs_find
  *
- * query cscope using command line interface.  parse the output and use tselect
- * to allow choices.  like Nvi, creates a pipe to send to/from query/cscope.
+ * Query cscope using command line interface.  Parse the output and use tselect
+ * to allow choices.  Like Nvi, creates a pipe to send to/from query/cscope.
  *
  * returns TRUE if we jump to a tag or abort, FALSE if not.
  */
     static int
-cs_find(eap)
-    exarg_T *eap;
+cs_find(exarg_T *eap)
 {
     char *opt, *pat;
     int i;
@@ -1102,13 +1108,13 @@ cs_find(eap)
  * common code for cscope find, shared by cs_find() and do_cstag()
  */
     static int
-cs_find_common(opt, pat, forceit, verbose, use_ll, cmdline)
-    char *opt;
-    char *pat;
-    int forceit;
-    int verbose;
-    int	use_ll;
-    char_u *cmdline;
+cs_find_common(
+    char *opt,
+    char *pat,
+    int forceit,
+    int verbose,
+    int	use_ll UNUSED,
+    char_u *cmdline UNUSED)
 {
     int i;
     char *cmd;
@@ -1190,11 +1196,13 @@ cs_find_common(opt, pat, forceit, verbose, use_ll, cmdline)
 
     nummatches = (int *)alloc(sizeof(int)*csinfo_size);
     if (nummatches == NULL)
+    {
+	vim_free(cmd);
 	return FALSE;
+    }
 
-    /* send query to all open connections, then count the total number
-     * of matches so we can alloc matchesp all in one swell foop
-     */
+    /* Send query to all open connections, then count the total number
+     * of matches so we can alloc all in one swell foop. */
     for (i = 0; i < csinfo_size; i++)
 	nummatches[i] = 0;
     totmatches = 0;
@@ -1246,7 +1254,7 @@ cs_find_common(opt, pat, forceit, verbose, use_ll, cmdline)
     {
 	/* fill error list */
 	FILE	    *f;
-	char_u	    *tmp = vim_tempname('c');
+	char_u	    *tmp = vim_tempname('c', TRUE);
 	qf_info_T   *qi = NULL;
 	win_T	    *wp = NULL;
 
@@ -1266,7 +1274,7 @@ cs_find_common(opt, pat, forceit, verbose, use_ll, cmdline)
 # ifdef FEAT_WINDOWS
 		if (postponed_split != 0)
 		{
-		    win_split(postponed_split > 0 ? postponed_split : 0,
+		    (void)win_split(postponed_split > 0 ? postponed_split : 0,
 						       postponed_split_flags);
 		    RESET_BINDING(curwin);
 		    postponed_split = 0;
@@ -1318,8 +1326,7 @@ cs_find_common(opt, pat, forceit, verbose, use_ll, cmdline)
  * print help
  */
     static int
-cs_help(eap)
-    exarg_T *eap UNUSED;
+cs_help(exarg_T *eap UNUSED)
 {
     cscmd_T *cmdp = cs_cmds;
 
@@ -1356,8 +1363,7 @@ cs_help(eap)
 
 
     static void
-clear_csinfo(i)
-    int	    i;
+clear_csinfo(int i)
 {
     csinfo[i].fname  = NULL;
     csinfo[i].ppath  = NULL;
@@ -1379,10 +1385,10 @@ clear_csinfo(i)
 }
 
 #ifndef UNIX
-static char *GetWin32Error __ARGS((void));
+static char *GetWin32Error(void);
 
     static char *
-GetWin32Error()
+GetWin32Error(void)
 {
     char *msg = NULL;
     FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER|FORMAT_MESSAGE_FROM_SYSTEM,
@@ -1404,11 +1410,11 @@ GetWin32Error()
  * insert a new cscope database filename into the filelist
  */
     static int
-cs_insert_filelist(fname, ppath, flags, sb)
-    char *fname;
-    char *ppath;
-    char *flags;
-    struct stat *sb UNUSED;
+cs_insert_filelist(
+    char *fname,
+    char *ppath,
+    char *flags,
+    struct stat *sb UNUSED)
 {
     short	i, j;
 #ifndef UNIX
@@ -1417,7 +1423,7 @@ cs_insert_filelist(fname, ppath, flags, sb)
     /* On windows 9x GetFileInformationByHandle doesn't work, so skip it */
     if (!mch_windows95())
     {
-	switch (win32_fileinfo(fname, &bhfi))
+	switch (win32_fileinfo((char_u *)fname, &bhfi))
 	{
 	case FILEINFO_ENC_FAIL:		/* enc_to_utf16() failed */
 	case FILEINFO_READ_FAIL:	/* CreateFile() failed */
@@ -1453,7 +1459,8 @@ cs_insert_filelist(fname, ppath, flags, sb)
 	    && csinfo[j].st_dev == sb->st_dev && csinfo[j].st_ino == sb->st_ino
 #else
 	    /* compare pathnames first */
-	    && ((fullpathcmp(csinfo[j].fname, fname, FALSE) & FPC_SAME)
+	    && ((fullpathcmp((char_u *)csinfo[j].fname,
+			(char_u *)fname, FALSE) & FPC_SAME)
 		/* if not Windows 9x, test index file attributes too */
 		|| (!mch_windows95()
 		    && csinfo[j].nVolume == bhfi.dwVolumeSerialNumber
@@ -1484,9 +1491,16 @@ cs_insert_filelist(fname, ppath, flags, sb)
 	}
 	else
 	{
+	    csinfo_T *t_csinfo = csinfo;
+
 	    /* Reallocate space for more connections. */
 	    csinfo_size *= 2;
 	    csinfo = vim_realloc(csinfo, sizeof(csinfo_T)*csinfo_size);
+	    if (csinfo == NULL)
+	    {
+		vim_free(t_csinfo);
+		csinfo_size = 0;
+	    }
 	}
 	if (csinfo == NULL)
 	    return -1;
@@ -1544,8 +1558,7 @@ cs_insert_filelist(fname, ppath, flags, sb)
  * find cscope command in command table
  */
     static cscmd_T *
-cs_lookup_cmd(eap)
-    exarg_T *eap;
+cs_lookup_cmd(exarg_T *eap)
 {
     cscmd_T *cmdp;
     char *stok;
@@ -1576,8 +1589,7 @@ cs_lookup_cmd(eap)
  * nuke em
  */
     static int
-cs_kill(eap)
-    exarg_T *eap UNUSED;
+cs_kill(exarg_T *eap UNUSED)
 {
     char *stok;
     short i;
@@ -1634,9 +1646,9 @@ cs_kill(eap)
  * Actually kills a specific cscope connection.
  */
     static void
-cs_kill_execute(i, cname)
-    int i;	    /* cscope table index */
-    char *cname;    /* cscope database name */
+cs_kill_execute(
+    int i,	    /* cscope table index */
+    char *cname)    /* cscope database name */
 {
     if (p_csverbose)
     {
@@ -1669,11 +1681,11 @@ cs_kill_execute(i, cname)
  * characters to comply with ctags formatting.
  */
     static char *
-cs_make_vim_style_matches(fname, slno, search, tagstr)
-    char *fname;
-    char *slno;
-    char *search;
-    char *tagstr;
+cs_make_vim_style_matches(
+    char *fname,
+    char *slno,
+    char *search,
+    char *tagstr)
 {
     /* vim style is ctags:
      *
@@ -1729,11 +1741,11 @@ cs_make_vim_style_matches(fname, slno, search, tagstr)
  * Print: prints the tags
  */
     static char *
-cs_manage_matches(matches, contexts, totmatches, cmd)
-    char **matches;
-    char **contexts;
-    int totmatches;
-    mcmd_e cmd;
+cs_manage_matches(
+    char **matches,
+    char **contexts,
+    int totmatches,
+    mcmd_e cmd)
 {
     static char **mp = NULL;
     static char **cp = NULL;
@@ -1796,13 +1808,13 @@ cs_manage_matches(matches, contexts, totmatches, cmd)
  * parse cscope output
  */
     static char *
-cs_parse_results(cnumber, buf, bufsize, context, linenumber, search)
-    int cnumber;
-    char *buf;
-    int bufsize;
-    char **context;
-    char **linenumber;
-    char **search;
+cs_parse_results(
+    int cnumber,
+    char *buf,
+    int bufsize,
+    char **context,
+    char **linenumber,
+    char **search)
 {
     int ch;
     char *p;
@@ -1859,9 +1871,7 @@ cs_parse_results(cnumber, buf, bufsize, context, linenumber, search)
  * write cscope find results to file
  */
     static void
-cs_file_results(f, nummatches_a)
-    FILE *f;
-    int *nummatches_a;
+cs_file_results(FILE *f, int *nummatches_a)
 {
     int i, j;
     char *buf;
@@ -1918,13 +1928,13 @@ cs_file_results(f, nummatches_a)
  * When there are no matches sets "*matches_p" to NULL.
  */
     static void
-cs_fill_results(tagstr, totmatches, nummatches_a, matches_p, cntxts_p, matched)
-    char *tagstr;
-    int totmatches;
-    int *nummatches_a;
-    char ***matches_p;
-    char ***cntxts_p;
-    int *matched;
+cs_fill_results(
+    char *tagstr,
+    int totmatches,
+    int *nummatches_a,
+    char ***matches_p,
+    char ***cntxts_p,
+    int *matched)
 {
     int i, j;
     char *buf;
@@ -1998,8 +2008,7 @@ parse_out:
 
 /* get the requested path components */
     static char *
-cs_pathcomponents(path)
-    char	*path;
+cs_pathcomponents(char *path)
 {
     int		i;
     char	*s;
@@ -2030,12 +2039,10 @@ cs_pathcomponents(path)
  * called from cs_manage_matches()
  */
     static void
-cs_print_tags_priv(matches, cntxts, num_matches)
-    char **matches;
-    char **cntxts;
-    int num_matches;
+cs_print_tags_priv(char **matches, char **cntxts, int num_matches)
 {
     char	*buf = NULL;
+    char	*t_buf;
     int		bufsize = 0; /* Track available bufsize */
     int		newsize = 0;
     char	*ptag;
@@ -2054,6 +2061,11 @@ cs_print_tags_priv(matches, cntxts, num_matches)
 
     strcpy(tbuf, matches[0]);
     ptag = strtok(tbuf, "\t");
+    if (ptag == NULL)
+    {
+	vim_free(tbuf);
+	return;
+    }
 
     newsize = (int)(strlen(cstag_msg) + strlen(ptag));
     buf = (char *)alloc(newsize);
@@ -2083,12 +2095,13 @@ cs_print_tags_priv(matches, cntxts, num_matches)
 	    continue;
 	(void)strcpy(tbuf, matches[idx]);
 
-	if (strtok(tbuf, (const char *)"\t") == NULL)
-	    continue;
-	if ((fname = strtok(NULL, (const char *)"\t")) == NULL)
-	    continue;
-	if ((lno = strtok(NULL, (const char *)"\t")) == NULL)
+	if (strtok(tbuf, (const char *)"\t") == NULL
+		|| (fname = strtok(NULL, (const char *)"\t")) == NULL
+		|| (lno = strtok(NULL, (const char *)"\t")) == NULL)
+	{
+	    vim_free(tbuf);
 	    continue;
+	}
 	extra = strtok(NULL, (const char *)"\t");
 
 	lno[strlen(lno)-2] = '\0';  /* ignore ;" at the end */
@@ -2097,9 +2110,13 @@ cs_print_tags_priv(matches, cntxts, num_matches)
 	newsize = (int)(strlen(csfmt_str) + 16 + strlen(lno));
 	if (bufsize < newsize)
 	{
+	    t_buf = buf;
 	    buf = (char *)vim_realloc(buf, newsize);
 	    if (buf == NULL)
+	    {
 		bufsize = 0;
+		vim_free(t_buf);
+	    }
 	    else
 		bufsize = newsize;
 	}
@@ -2120,9 +2137,13 @@ cs_print_tags_priv(matches, cntxts, num_matches)
 
 	if (bufsize < newsize)
 	{
+	    t_buf = buf;
 	    buf = (char *)vim_realloc(buf, newsize);
 	    if (buf == NULL)
+	    {
 		bufsize = 0;
+		vim_free(t_buf);
+	    }
 	    else
 		bufsize = newsize;
 	}
@@ -2168,8 +2189,7 @@ cs_print_tags_priv(matches, cntxts, num_matches)
  * read a cscope prompt (basically, skip over the ">> ")
  */
     static int
-cs_read_prompt(i)
-    int i;
+cs_read_prompt(int i)
 {
     int		ch;
     char	*buf = NULL; /* buffer for possible error message from cscope */
@@ -2268,9 +2288,7 @@ sig_handler SIGDEFARG(sigarg)
  * or not to free the filename.  Called by cs_kill and cs_reset.
  */
     static void
-cs_release_csp(i, freefnpp)
-    int i;
-    int freefnpp;
+cs_release_csp(int i, int freefnpp)
 {
     /*
      * Trying to exit normally (not sure whether it is fit to UNIX cscope
@@ -2397,8 +2415,7 @@ cs_release_csp(i, freefnpp)
  * calls cs_kill on all cscope connections then reinits
  */
     static int
-cs_reset(eap)
-    exarg_T *eap UNUSED;
+cs_reset(exarg_T *eap UNUSED)
 {
     char	**dblist = NULL, **pplist = NULL, **fllist = NULL;
     int	i;
@@ -2461,18 +2478,16 @@ cs_reset(eap)
 /*
  * PRIVATE: cs_resolve_file
  *
- * construct the full pathname to a file found in the cscope database.
+ * Construct the full pathname to a file found in the cscope database.
  * (Prepends ppath, if there is one and if it's not already prepended,
  * otherwise just uses the name found.)
  *
- * we need to prepend the prefix because on some cscope's (e.g., the one that
+ * We need to prepend the prefix because on some cscope's (e.g., the one that
  * ships with Solaris 2.6), the output never has the prefix prepended.
- * contrast this with my development system (Digital Unix), which does.
+ * Contrast this with my development system (Digital Unix), which does.
  */
     static char *
-cs_resolve_file(i, name)
-    int  i;
-    char *name;
+cs_resolve_file(int i, char *name)
 {
     char	*fullname;
     int		len;
@@ -2494,14 +2509,12 @@ cs_resolve_file(i, name)
 	if (csdir != NULL)
 	{
 	    vim_strncpy(csdir, (char_u *)csinfo[i].fname,
-		    gettail((char_u *)csinfo[i].fname) - 1 - (char_u *)csinfo[i].fname);
+		                       gettail((char_u *)csinfo[i].fname)
+						 - (char_u *)csinfo[i].fname);
 	    len += (int)STRLEN(csdir);
 	}
     }
 
-    if ((fullname = (char *)alloc(len)) == NULL)
-	return NULL;
-
     /* Note/example: this won't work if the cscope output already starts
      * "../.." and the prefix path is also "../..".  if something like this
      * happens, you are screwed up and need to fix how you're using cscope. */
@@ -2512,16 +2525,20 @@ cs_resolve_file(i, name)
 	    && name[0] != '\\' && name[1] != ':'
 #endif
        )
-	(void)sprintf(fullname, "%s/%s", csinfo[i].ppath, name);
-    else if (csdir != NULL && csinfo[i].fname != NULL && STRLEN(csdir) > 0)
+    {
+	if ((fullname = (char *)alloc(len)) != NULL)
+	    (void)sprintf(fullname, "%s/%s", csinfo[i].ppath, name);
+    }
+    else if (csdir != NULL && csinfo[i].fname != NULL && *csdir != NUL)
     {
 	/* Check for csdir to be non empty to avoid empty path concatenated to
-	 * cscope output. TODO: avoid the unnecessary alloc/free of fullname. */
-	vim_free(fullname);
+	 * cscope output. */
 	fullname = (char *)concat_fnames(csdir, (char_u *)name, TRUE);
     }
     else
-	(void)sprintf(fullname, "%s", name);
+    {
+	fullname = (char *)vim_strsave((char_u *)name);
+    }
 
     vim_free(csdir);
     return fullname;
@@ -2534,8 +2551,7 @@ cs_resolve_file(i, name)
  * show all cscope connections
  */
     static int
-cs_show(eap)
-    exarg_T *eap UNUSED;
+cs_show(exarg_T *eap UNUSED)
 {
     short i;
     if (cs_cnt_connections() == 0)
@@ -2570,7 +2586,7 @@ cs_show(eap)
  * Only called when VIM exits to quit any cscope sessions.
  */
     void
-cs_end()
+cs_end(void)
 {
     int i;
 
