@@ -4,6 +4,7 @@
  *
  * Do ":help uganda"  in Vim to read copying and usage conditions.
  * Do ":help credits" in Vim to see a list of people who contributed.
+ * See README.txt for an overview of the Vim source code.
  */
 /*
  * if_perlsfio.c: Special I/O functions for Perl interface.
@@ -14,29 +15,21 @@
 
 #include "vim.h"
 
-/*
- * Avoid clashes between Perl and Vim namespace.
- */
-#undef MAGIC
-#undef NORMAL
-#undef STRLEN
-#undef FF
-#undef OP_DELETE
+#if defined(USE_SFIO) || defined(PROTO)
 
-#include <EXTERN.h>
-#include <perl.h>
-#include <XSUB.h>
-
-#ifdef USE_SFIO
+#ifndef USE_SFIO	/* just generating prototypes */
+# define Sfio_t int
+# define Sfdisc_t int
+#endif
 
 #define NIL(type)	((type)0)
 
     static int
-sfvimwrite(f, buf, n, disc)
-    Sfio_t	    *f;		/* stream involved */
-    char	    *buf;	/* buffer to read from */
-    int		    n;		/* number of bytes to write */
-    Sfdisc_t	    *disc;	/* discipline */
+sfvimwrite(
+    Sfio_t	    *f,		/* stream involved */
+    char	    *buf,	/* buffer to read from */
+    int		    n,		/* number of bytes to write */
+    Sfdisc_t	    *disc)	/* discipline */
 {
     char_u *str;
 
@@ -54,11 +47,11 @@ sfvimwrite(f, buf, n, disc)
  *  Create Vim discipline
  */
     Sfdisc_t *
-sfdcnewvim()
+sfdcnewvim(void)
 {
     Sfdisc_t	*disc;
 
-    disc = (Sfdisc_t *)malloc(sizeof(Sfdisc_t));
+    disc = (Sfdisc_t *)alloc((unsigned)sizeof(Sfdisc_t));
     if (disc == NULL)
 	return NULL;
 
