@@ -27,15 +27,15 @@
 #define EXTRA_MARKS 10					/* marks 0-9 */
 static xfmark_T namedfm[NMARKS + EXTRA_MARKS];		/* marks with file nr */
 
-static void fname2fnum __ARGS((xfmark_T *fm));
-static void fmarks_check_one __ARGS((xfmark_T *fm, char_u *name, buf_T *buf));
-static char_u *mark_line __ARGS((pos_T *mp, int lead_len));
-static void show_one_mark __ARGS((int, char_u *, pos_T *, char_u *, int current));
+static void fname2fnum(xfmark_T *fm);
+static void fmarks_check_one(xfmark_T *fm, char_u *name, buf_T *buf);
+static char_u *mark_line(pos_T *mp, int lead_len);
+static void show_one_mark(int, char_u *, pos_T *, char_u *, int current);
 #ifdef FEAT_JUMPLIST
-static void cleanup_jumplist __ARGS((void));
+static void cleanup_jumplist(void);
 #endif
 #ifdef FEAT_VIMINFO
-static void write_one_filemark __ARGS((FILE *fp, xfmark_T *fm, int c1, int c2));
+static void write_one_filemark(FILE *fp, xfmark_T *fm, int c1, int c2);
 #endif
 
 /*
@@ -43,8 +43,7 @@ static void write_one_filemark __ARGS((FILE *fp, xfmark_T *fm, int c1, int c2));
  * Returns OK on success, FAIL if bad name given.
  */
     int
-setmark(c)
-    int		c;
+setmark(int c)
 {
     return setmark_pos(c, &curwin->w_cursor, curbuf->b_fnum);
 }
@@ -55,10 +54,7 @@ setmark(c)
  * Returns OK on success, FAIL if bad name given.
  */
     int
-setmark_pos(c, pos, fnum)
-    int		c;
-    pos_T	*pos;
-    int		fnum;
+setmark_pos(int c, pos_T *pos, int fnum)
 {
     int		i;
 
@@ -98,6 +94,18 @@ setmark_pos(c, pos, fnum)
 	return OK;
     }
 
+    if (c == '<' || c == '>')
+    {
+	if (c == '<')
+	    curbuf->b_visual.vi_start = *pos;
+	else
+	    curbuf->b_visual.vi_end = *pos;
+	if (curbuf->b_visual.vi_mode == NUL)
+	    /* Visual_mode has not yet been set, use a sane default. */
+	    curbuf->b_visual.vi_mode = 'v';
+	return OK;
+    }
+
 #ifndef EBCDIC
     if (c > 'z')	    /* some islower() and isupper() cannot handle
 				characters above 127 */
@@ -126,7 +134,7 @@ setmark_pos(c, pos, fnum)
  * jump list.
  */
     void
-setpcmark()
+setpcmark(void)
 {
 #ifdef FEAT_JUMPLIST
     int		i;
@@ -186,7 +194,7 @@ setpcmark()
  * If pcmark was deleted (with "dG") the previous mark is restored.
  */
     void
-checkpcmark()
+checkpcmark(void)
 {
     if (curwin->w_prev_pcmark.lnum != 0
 	    && (equalpos(curwin->w_pcmark, curwin->w_cursor)
@@ -202,8 +210,7 @@ checkpcmark()
  * move "count" positions in the jump list (count may be negative)
  */
     pos_T *
-movemark(count)
-    int count;
+movemark(int count)
 {
     pos_T	*pos;
     xfmark_T	*jmp;
@@ -262,8 +269,7 @@ movemark(count)
  * Move "count" positions in the changelist (count may be negative).
  */
     pos_T *
-movechangelist(count)
-    int		count;
+movechangelist(int count)
 {
     int		n;
 
@@ -291,7 +297,7 @@ movechangelist(count)
 #endif
 
 /*
- * Find mark "c".
+ * Find mark "c" in buffer pointed to by "buf".
  * If "changefile" is TRUE it's allowed to edit another file for '0, 'A, etc.
  * If "fnum" is not NULL store the fnum there for '0, 'A etc., don't edit
  * another file.
@@ -302,23 +308,26 @@ movechangelist(count)
  * - -1 if mark is in other file and jumped there (only if changefile is TRUE)
  */
     pos_T *
-getmark(c, changefile)
-    int		c;
-    int		changefile;
+getmark_buf(buf_T *buf, int c, int changefile)
 {
-    return getmark_fnum(c, changefile, NULL);
+    return getmark_buf_fnum(buf, c, changefile, NULL);
 }
 
     pos_T *
-getmark_fnum(c, changefile, fnum)
-    int		c;
-    int		changefile;
-    int		*fnum;
+getmark(int c, int changefile)
+{
+    return getmark_buf_fnum(curbuf, c, changefile, NULL);
+}
+
+    pos_T *
+getmark_buf_fnum(
+    buf_T	*buf,
+    int		c,
+    int		changefile,
+    int		*fnum)
 {
     pos_T		*posp;
-#ifdef FEAT_VISUAL
     pos_T		*startp, *endp;
-#endif
     static pos_T	pos_copy;
 
     posp = NULL;
@@ -338,15 +347,15 @@ getmark_fnum(c, changefile, fnum)
 	posp = &pos_copy;		/*   w_pcmark may be changed soon */
     }
     else if (c == '"')			/* to pos when leaving buffer */
-	posp = &(curbuf->b_last_cursor);
+	posp = &(buf->b_last_cursor);
     else if (c == '^')			/* to where Insert mode stopped */
-	posp = &(curbuf->b_last_insert);
+	posp = &(buf->b_last_insert);
     else if (c == '.')			/* to where last change was made */
-	posp = &(curbuf->b_last_change);
+	posp = &(buf->b_last_change);
     else if (c == '[')			/* to start of previous operator */
-	posp = &(curbuf->b_op_start);
+	posp = &(buf->b_op_start);
     else if (c == ']')			/* to end of previous operator */
-	posp = &(curbuf->b_op_end);
+	posp = &(buf->b_op_end);
     else if (c == '{' || c == '}')	/* to previous/next paragraph */
     {
 	pos_T	pos;
@@ -379,11 +388,10 @@ getmark_fnum(c, changefile, fnum)
 	curwin->w_cursor = pos;
 	listcmd_busy = slcb;
     }
-#ifdef FEAT_VISUAL
     else if (c == '<' || c == '>')	/* start/end of visual area */
     {
-	startp = &curbuf->b_visual.vi_start;
-	endp = &curbuf->b_visual.vi_end;
+	startp = &buf->b_visual.vi_start;
+	endp = &buf->b_visual.vi_end;
 	if ((c == '<') == lt(*startp, *endp))
 	    posp = startp;
 	else
@@ -391,7 +399,7 @@ getmark_fnum(c, changefile, fnum)
 	/*
 	 * For Visual line mode, set mark at begin or end of line
 	 */
-	if (curbuf->b_visual.vi_mode == 'V')
+	if (buf->b_visual.vi_mode == 'V')
 	{
 	    pos_copy = *posp;
 	    posp = &pos_copy;
@@ -404,10 +412,9 @@ getmark_fnum(c, changefile, fnum)
 #endif
 	}
     }
-#endif
     else if (ASCII_ISLOWER(c))		/* normal named mark */
     {
-	posp = &(curbuf->b_namedm[c - 'a']);
+	posp = &(buf->b_namedm[c - 'a']);
     }
     else if (ASCII_ISUPPER(c) || VIM_ISDIGIT(c))	/* named file mark */
     {
@@ -422,7 +429,7 @@ getmark_fnum(c, changefile, fnum)
 
 	if (fnum != NULL)
 	    *fnum = namedfm[c].fmark.fnum;
-	else if (namedfm[c].fmark.fnum != curbuf->b_fnum)
+	else if (namedfm[c].fmark.fnum != buf->b_fnum)
 	{
 	    /* mark is in another file */
 	    posp = &pos_copy;
@@ -454,10 +461,10 @@ getmark_fnum(c, changefile, fnum)
  * Returns pointer to pos_T of the next mark or NULL if no mark is found.
  */
     pos_T *
-getnextmark(startpos, dir, begin_line)
-    pos_T	*startpos;	/* where to start */
-    int		dir;	/* direction for search */
-    int		begin_line;
+getnextmark(
+    pos_T	*startpos,	/* where to start */
+    int		dir,	/* direction for search */
+    int		begin_line)
 {
     int		i;
     pos_T	*result = NULL;
@@ -502,8 +509,7 @@ getnextmark(startpos, dir, begin_line)
  * until the mark is used to avoid a long startup delay.
  */
     static void
-fname2fnum(fm)
-    xfmark_T	*fm;
+fname2fnum(xfmark_T *fm)
 {
     char_u	*p;
 
@@ -543,8 +549,7 @@ fname2fnum(fm)
  * Used for marks that come from the .viminfo file.
  */
     void
-fmarks_check_names(buf)
-    buf_T	*buf;
+fmarks_check_names(buf_T *buf)
 {
     char_u	*name;
     int		i;
@@ -574,10 +579,7 @@ fmarks_check_names(buf)
 }
 
     static void
-fmarks_check_one(fm, name, buf)
-    xfmark_T	*fm;
-    char_u	*name;
-    buf_T	*buf;
+fmarks_check_one(xfmark_T *fm, char_u *name, buf_T *buf)
 {
     if (fm->fmark.fnum == 0
 	    && fm->fname != NULL
@@ -594,8 +596,7 @@ fmarks_check_one(fm, name, buf)
  * Give and error message and return FAIL if not.
  */
     int
-check_mark(pos)
-    pos_T    *pos;
+check_mark(pos_T *pos)
 {
     if (pos == NULL)
     {
@@ -624,8 +625,7 @@ check_mark(pos)
  * Used mainly when trashing the entire buffer during ":e" type commands
  */
     void
-clrallmarks(buf)
-    buf_T	*buf;
+clrallmarks(buf_T *buf)
 {
     static int		i = -1;
 
@@ -658,9 +658,7 @@ clrallmarks(buf)
  * Returns an allocated string.
  */
     char_u *
-fm_getname(fmark, lead_len)
-    fmark_T	*fmark;
-    int		lead_len;
+fm_getname(fmark_T *fmark, int lead_len)
 {
     if (fmark->fnum == curbuf->b_fnum)		    /* current buffer */
 	return mark_line(&(fmark->mark), lead_len);
@@ -672,9 +670,7 @@ fm_getname(fmark, lead_len)
  * The returned string has been allocated.
  */
     static char_u *
-mark_line(mp, lead_len)
-    pos_T	*mp;
-    int		lead_len;
+mark_line(pos_T *mp, int lead_len)
 {
     char_u	*s, *p;
     int		len;
@@ -700,8 +696,7 @@ mark_line(mp, lead_len)
  * print the marks
  */
     void
-do_marks(eap)
-    exarg_T	*eap;
+do_marks(exarg_T *eap)
 {
     char_u	*arg = eap->arg;
     int		i;
@@ -733,20 +728,18 @@ do_marks(eap)
     show_one_mark(']', arg, &curbuf->b_op_end, NULL, TRUE);
     show_one_mark('^', arg, &curbuf->b_last_insert, NULL, TRUE);
     show_one_mark('.', arg, &curbuf->b_last_change, NULL, TRUE);
-#ifdef FEAT_VISUAL
     show_one_mark('<', arg, &curbuf->b_visual.vi_start, NULL, TRUE);
     show_one_mark('>', arg, &curbuf->b_visual.vi_end, NULL, TRUE);
-#endif
     show_one_mark(-1, arg, NULL, NULL, FALSE);
 }
 
     static void
-show_one_mark(c, arg, p, name, current)
-    int		c;
-    char_u	*arg;
-    pos_T	*p;
-    char_u	*name;
-    int		current;	/* in current file */
+show_one_mark(
+    int		c,
+    char_u	*arg,
+    pos_T	*p,
+    char_u	*name,
+    int		current)	/* in current file */
 {
     static int	did_title = FALSE;
     int		mustfree = FALSE;
@@ -799,8 +792,7 @@ show_one_mark(c, arg, p, name, current)
  * ":delmarks[!] [marks]"
  */
     void
-ex_delmarks(eap)
-    exarg_T *eap;
+ex_delmarks(exarg_T *eap)
 {
     char_u	*p;
     int		from, to;
@@ -868,10 +860,8 @@ ex_delmarks(eap)
 		    case '.': curbuf->b_last_change.lnum = 0; break;
 		    case '[': curbuf->b_op_start.lnum    = 0; break;
 		    case ']': curbuf->b_op_end.lnum      = 0; break;
-#ifdef FEAT_VISUAL
 		    case '<': curbuf->b_visual.vi_start.lnum = 0; break;
 		    case '>': curbuf->b_visual.vi_end.lnum   = 0; break;
-#endif
 		    case ' ': break;
 		    default:  EMSG2(_(e_invarg2), p);
 			      return;
@@ -884,10 +874,8 @@ ex_delmarks(eap)
 /*
  * print the jumplist
  */
-/*ARGSUSED*/
     void
-ex_jumps(eap)
-    exarg_T	*eap;
+ex_jumps(exarg_T *eap UNUSED)
 {
     int		i;
     char_u	*name;
@@ -933,10 +921,8 @@ ex_jumps(eap)
 /*
  * print the changelist
  */
-/*ARGSUSED*/
     void
-ex_changes(eap)
-    exarg_T	*eap;
+ex_changes(exarg_T *eap UNUSED)
 {
     int		i;
     char_u	*name;
@@ -1013,16 +999,20 @@ ex_changes(eap)
  *				   or: mark_adjust(56, 55, MAXLNUM, 2);
  */
     void
-mark_adjust(line1, line2, amount, amount_after)
-    linenr_T	line1;
-    linenr_T	line2;
-    long	amount;
-    long	amount_after;
+mark_adjust(
+    linenr_T	line1,
+    linenr_T	line2,
+    long	amount,
+    long	amount_after)
 {
     int		i;
     int		fnum = curbuf->b_fnum;
     linenr_T	*lp;
     win_T	*win;
+#ifdef FEAT_WINDOWS
+    tabpage_T	*tab;
+#endif
+    static pos_T initpos = INIT_POS_T(1, 0, 0);
 
     if (line2 < line1 && amount_after == 0L)	    /* nothing to do */
 	return;
@@ -1048,23 +1038,26 @@ mark_adjust(line1, line2, amount, amount_after)
 	/* last change position */
 	one_adjust(&(curbuf->b_last_change.lnum));
 
+	/* last cursor position, if it was set */
+	if (!equalpos(curbuf->b_last_cursor, initpos))
+	    one_adjust(&(curbuf->b_last_cursor.lnum));
+
+
 #ifdef FEAT_JUMPLIST
 	/* list of change positions */
 	for (i = 0; i < curbuf->b_changelistlen; ++i)
 	    one_adjust_nodel(&(curbuf->b_changelist[i].lnum));
 #endif
 
-#ifdef FEAT_VISUAL
 	/* Visual area */
 	one_adjust_nodel(&(curbuf->b_visual.vi_start.lnum));
 	one_adjust_nodel(&(curbuf->b_visual.vi_end.lnum));
-#endif
 
 #ifdef FEAT_QUICKFIX
 	/* quickfix marks */
 	qf_mark_adjust(NULL, line1, line2, amount, amount_after);
 	/* location lists */
-	FOR_ALL_WINDOWS(win)
+	FOR_ALL_TAB_WINDOWS(tab, win)
 	    qf_mark_adjust(win, line1, line2, amount, amount_after);
 #endif
 
@@ -1086,7 +1079,7 @@ mark_adjust(line1, line2, amount, amount_after)
     /*
      * Adjust items in all windows related to the current buffer.
      */
-    FOR_ALL_WINDOWS(win)
+    FOR_ALL_TAB_WINDOWS(tab, win)
     {
 #ifdef FEAT_JUMPLIST
 	if (!cmdmod.lockmarks)
@@ -1105,14 +1098,12 @@ mark_adjust(line1, line2, amount, amount_after)
 		    if (win->w_tagstack[i].fmark.fnum == fnum)
 			one_adjust_nodel(&(win->w_tagstack[i].fmark.mark.lnum));
 
-#ifdef FEAT_VISUAL
 	    /* the displayed Visual area */
 	    if (win->w_old_cursor_lnum != 0)
 	    {
 		one_adjust_nodel(&(win->w_old_cursor_lnum));
 		one_adjust_nodel(&(win->w_old_visual_lnum));
 	    }
-#endif
 
 	    /* topline and cursor position for windows with the same buffer
 	     * other than the current window */
@@ -1190,11 +1181,11 @@ mark_adjust(line1, line2, amount, amount_after)
  * position.
  */
     void
-mark_col_adjust(lnum, mincol, lnum_amount, col_amount)
-    linenr_T	lnum;
-    colnr_T	mincol;
-    long	lnum_amount;
-    long	col_amount;
+mark_col_adjust(
+    linenr_T	lnum,
+    colnr_T	mincol,
+    long	lnum_amount,
+    long	col_amount)
 {
     int		i;
     int		fnum = curbuf->b_fnum;
@@ -1229,11 +1220,9 @@ mark_col_adjust(lnum, mincol, lnum_amount, col_amount)
 	col_adjust(&(curbuf->b_changelist[i]));
 #endif
 
-#ifdef FEAT_VISUAL
     /* Visual area */
     col_adjust(&(curbuf->b_visual.vi_start));
     col_adjust(&(curbuf->b_visual.vi_end));
-#endif
 
     /* previous context mark */
     col_adjust(&(curwin->w_pcmark));
@@ -1276,7 +1265,7 @@ mark_col_adjust(lnum, mincol, lnum_amount, col_amount)
  * jumplist. They will be removed here for the current window.
  */
     static void
-cleanup_jumplist()
+cleanup_jumplist(void)
 {
     int	    i;
     int	    from, to;
@@ -1308,9 +1297,7 @@ cleanup_jumplist()
  * Copy the jumplist from window "from" to window "to".
  */
     void
-copy_jumplist(from, to)
-    win_T	*from;
-    win_T	*to;
+copy_jumplist(win_T *from, win_T *to)
 {
     int		i;
 
@@ -1328,8 +1315,7 @@ copy_jumplist(from, to)
  * Free items in the jumplist of window "wp".
  */
     void
-free_jumplist(wp)
-    win_T	*wp;
+free_jumplist(win_T *wp)
 {
     int		i;
 
@@ -1340,15 +1326,15 @@ free_jumplist(wp)
 #endif /* FEAT_JUMPLIST */
 
     void
-set_last_cursor(win)
-    win_T	*win;
+set_last_cursor(win_T *win)
 {
-    win->w_buffer->b_last_cursor = win->w_cursor;
+    if (win->w_buffer != NULL)
+	win->w_buffer->b_last_cursor = win->w_cursor;
 }
 
 #if defined(EXITFREE) || defined(PROTO)
     void
-free_all_marks()
+free_all_marks(void)
 {
     int		i;
 
@@ -1360,9 +1346,7 @@ free_all_marks()
 
 #if defined(FEAT_VIMINFO) || defined(PROTO)
     int
-read_viminfo_filemark(virp, force)
-    vir_T	*virp;
-    int		force;
+read_viminfo_filemark(vir_T *virp, int force)
 {
     char_u	*str;
     xfmark_T	*fm;
@@ -1422,8 +1406,7 @@ read_viminfo_filemark(virp, force)
 }
 
     void
-write_viminfo_filemarks(fp)
-    FILE	*fp;
+write_viminfo_filemarks(FILE *fp)
 {
     int		i;
     char_u	*name;
@@ -1433,7 +1416,7 @@ write_viminfo_filemarks(fp)
     if (get_viminfo_parameter('f') == 0)
 	return;
 
-    fprintf(fp, _("\n# File marks:\n"));
+    fputs(_("\n# File marks:\n"), fp);
 
     /*
      * Find a mark that is the same file and position as the cursor.
@@ -1468,7 +1451,7 @@ write_viminfo_filemarks(fp)
 
 #ifdef FEAT_JUMPLIST
     /* Write the jumplist with -' */
-    fprintf(fp, _("\n# Jumplist (newest first):\n"));
+    fputs(_("\n# Jumplist (newest first):\n"), fp);
     setpcmark();	/* add current cursor position */
     cleanup_jumplist();
     for (fm = &curwin->w_jumplist[curwin->w_jumplistlen - 1];
@@ -1483,11 +1466,11 @@ write_viminfo_filemarks(fp)
 }
 
     static void
-write_one_filemark(fp, fm, c1, c2)
-    FILE	*fp;
-    xfmark_T	*fm;
-    int		c1;
-    int		c2;
+write_one_filemark(
+    FILE	*fp,
+    xfmark_T	*fm,
+    int		c1,
+    int		c2)
 {
     char_u	*name;
 
@@ -1513,8 +1496,7 @@ write_one_filemark(fp, fm, c1, c2)
  * Return TRUE if "name" is on removable media (depending on 'viminfo').
  */
     int
-removable(name)
-    char_u  *name;
+removable(char_u *name)
 {
     char_u  *p;
     char_u  part[51];
@@ -1542,15 +1524,14 @@ removable(name)
     return retval;
 }
 
-static void write_one_mark __ARGS((FILE *fp_out, int c, pos_T *pos));
+static void write_one_mark(FILE *fp_out, int c, pos_T *pos);
 
 /*
  * Write all the named marks for all buffers.
  * Return the number of buffers for which marks have been written.
  */
     int
-write_viminfo_marks(fp_out)
-    FILE	*fp_out;
+write_viminfo_marks(FILE *fp_out)
 {
     int		count;
     buf_T	*buf;
@@ -1569,7 +1550,7 @@ write_viminfo_marks(fp_out)
 	set_last_cursor(curwin);
 #endif
 
-    fprintf(fp_out, _("\n# History of marks within files (newest to oldest):\n"));
+    fputs(_("\n# History of marks within files (newest to oldest):\n"), fp_out);
     count = 0;
     for (buf = firstbuf; buf != NULL; buf = buf->b_next)
     {
@@ -1616,10 +1597,7 @@ write_viminfo_marks(fp_out)
 }
 
     static void
-write_one_mark(fp_out, c, pos)
-    FILE	*fp_out;
-    int		c;
-    pos_T	*pos;
+write_one_mark(FILE *fp_out, int c, pos_T *pos)
 {
     if (pos->lnum != 0)
 	fprintf(fp_out, "\t%c\t%ld\t%d\n", c, (long)pos->lnum, (int)pos->col);
@@ -1632,12 +1610,12 @@ write_one_mark(fp_out, c, pos)
  * fp_out == NULL && (flags & VIF_GET_OLDFILES | VIF_FORCEIT): fill v:oldfiles
  */
     void
-copy_viminfo_marks(virp, fp_out, count, eof, flags)
-    vir_T	*virp;
-    FILE	*fp_out;
-    int		count;
-    int		eof;
-    int		flags;
+copy_viminfo_marks(
+    vir_T	*virp,
+    FILE	*fp_out,
+    int		count,
+    int		eof,
+    int		flags)
 {
     char_u	*line = virp->vir_line;
     buf_T	*buf;
@@ -1749,7 +1727,10 @@ copy_viminfo_marks(virp, fp_out, count, eof, flags)
 	    {
 		if (line[1] != NUL)
 		{
-		    sscanf((char *)line + 2, "%ld %u", &pos.lnum, &pos.col);
+		    unsigned u;
+
+		    sscanf((char *)line + 2, "%ld %u", &pos.lnum, &u);
+		    pos.col = u;
 		    switch (line[1])
 		    {
 			case '"': curbuf->b_last_cursor = pos; break;
